@@ -1,10 +1,9 @@
 import datetime
 import os
 
-import pkginfo
+from xlrd.info import __VERSION__
 
 on_rtd = os.environ.get('READTHEDOCS', None) == 'True'
-pkg_info = pkginfo.Develop(os.path.join(os.path.dirname(__file__), os.pardir))
 
 intersphinx_mapping = {'http://docs.python.org': None}
 extensions = ['sphinx.ext.autodoc', 'sphinx.ext.intersphinx']
@@ -12,7 +11,7 @@ source_suffix = '.rst'
 master_doc = 'index'
 project = u'xlrd'
 copyright = '2005-%s Stephen John Machin, Lingfo Pty Ltd' % datetime.datetime.now().year
-version = release = pkg_info.version
+version = release = __VERSION__
 exclude_patterns = ['_build']
 pygments_style = 'sphinx'
 
