@@ -3,13 +3,13 @@ from unittest import TestCase
 from xlrd import open_workbook
 from xlrd.biffh import XL_CELL_TEXT
 
-from .base import from_this_dir
+from .helpers import from_sample
 
 
 class TestMissingRecords(TestCase):
 
     def setUp(self):
-        path = from_this_dir('biff4_no_format_no_window2.xls')
+        path = from_sample('biff4_no_format_no_window2.xls')
         self.book = open_workbook(path)
         self.sheet = self.book.sheet_by_index(0)
 
